==> lirc_0.9.4b.orig.tar.gz: api-docs/html/dir_97aefd0d527b934f1d99a682da8fe6a9.js <==
var dir_97aefd0d527b934f1d99a682da8fe6a9 =
[
    [ "ciniparser.c", "ciniparser_8c.html", "ciniparser_8c" ],
    [ "ciniparser.h", "ciniparser_8h.html", "ciniparser_8h" ],
    [ "config_file.c", "config__file_8c.html", "config__file_8c" ],
    [ "config_file.h", "config__file_8h.html", "config__file_8h" ],
    [ "config_flags.h", "config__flags_8h_source.html", null ],
    [ "dictionary.c", "dictionary_8c.html", "dictionary_8c" ],
    [ "dictionary.h", "dictionary_8h.html", "dictionary_8h" ],
    [ "driver.c", "driver_8c.html", "driver_8c" ],
    [ "driver.h", "driver_8h.html", "driver_8h" ],
    [ "drv_admin.c", "drv__admin_8c.html", "drv__admin_8c" ],
    [ "drv_admin.h", "drv__admin_8h.html", "drv__admin_8h" ],
    [ "dump_config.c", "dump__config_8c.html", "dump__config_8c" ],
    [ "dump_config.h", "dump__config_8h.html", "dump__config_8h" ],
    [ "input_map.c", "input__map_8c.html", "input__map_8c" ],
    [ "input_map.h", "input__map_8h.html", "input__map_8h" ],
    [ "input_map.inc", "input__map_8inc_source.html", null ],
    [ "ir_remote.c", "ir__remote_8c.html", "ir__remote_8c" ],
    [ "ir_remote.h", "ir__remote_8h.html", "ir__remote_8h" ],
    [ "ir_remote_types.h", "ir__remote__types_8h.html", "ir__remote__types_8h" ],
    [ "irrecord.c", "irrecord_8c_source.html", null ],
    [ "irrecord.h", "irrecord_8h_source.html", null ],
    [ "line_buffer.cpp", "line__buffer_8cpp.html", null ],
    [ "line_buffer.h", "line__buffer_8h_source.html", null ],
    [ "lirc_client.c", "lirc__client_8c.html", "lirc__client_8c" ],
    [ "lirc_client.h", "lirc__client_8h.html", "lirc__client_8h" ],
    [ "lirc_config.h", "lirc__config_8h.html", "lirc__config_8h" ],
    [ "lirc_driver.h", "lirc__driver_8h.html", "lirc__driver_8h" ],
    [ "lirc_log.c", "lirc__log_8c.html", "lirc__log_8c" ],
    [ "lirc_log.h", "lirc__log_8h.html", "lirc__log_8h" ],
    [ "lirc_options.c", "lirc__options_8c.html", "lirc__options_8c" ],
    [ "lirc_options.h", "lirc__options_8h.html", "lirc__options_8h" ],
    [ "lirc_private.h", "lirc__private_8h.html", null ],
    [ "paths.h", "paths_8h_source.html", null ],
    [ "receive.c", "receive_8c.html", "receive_8c" ],
    [ "receive.h", "receive_8h.html", "receive_8h" ],
    [ "release.c", "release_8c.html", "release_8c" ],
    [ "release.h", "release_8h.html", "release_8h" ],
    [ "serial.c", "serial_8c.html", "serial_8c" ],
    [ "serial.h", "serial_8h.html", "serial_8h" ],
    [ "transmit.c", "transmit_8c.html", "transmit_8c" ],
    [ "transmit.h", "transmit_8h.html", "transmit_8h" ],
    [ "util.c", "util_8c.html", "util_8c" ],
    [ "util.h", "util_8h.html", "util_8h" ]
];

==> lirc_0.10.0.orig.tar.gz: api-docs/html/dir_97aefd0d527b934f1d99a682da8fe6a9.js <==
var dir_97aefd0d527b934f1d99a682da8fe6a9 =
[
    [ "ciniparser.c", "ciniparser_8c.html", "ciniparser_8c" ],
    [ "ciniparser.h", "ciniparser_8h.html", "ciniparser_8h" ],
    [ "config_file.c", "config__file_8c.html", "config__file_8c" ],
    [ "config_file.h", "config__file_8h.html", "config__file_8h" ],
    [ "config_flags.h", "config__flags_8h.html", "config__flags_8h" ],
    [ "curl_poll.c", "curl__poll_8c.html", "curl__poll_8c" ],
    [ "curl_poll.h", "curl__poll_8h.html", "curl__poll_8h" ],
    [ "dictionary.c", "dictionary_8c.html", "dictionary_8c" ],
    [ "dictionary.h", "dictionary_8h.html", "dictionary_8h" ],
    [ "driver.c", "driver_8c.html", "driver_8c" ],
    [ "driver.h", "driver_8h.html", "driver_8h" ],
    [ "drv_admin.c", "drv__admin_8c.html", "drv__admin_8c" ],
    [ "drv_admin.h", "drv__admin_8h.html", "drv__admin_8h" ],
    [ "drv_enum.c", "drv__enum_8c.html", "drv__enum_8c" ],
    [ "drv_enum.h", "drv__enum_8h.html", "drv__enum_8h" ],
    [ "dump_config.c", "dump__config_8c.html", "dump__config_8c" ],
    [ "dump_config.h", "dump__config_8h.html", "dump__config_8h" ],
    [ "input_map.c", "input__map_8c.html", "input__map_8c" ],
    [ "input_map.h", "input__map_8h.html", "input__map_8h" ],
    [ "input_map.inc", "input__map_8inc_source.html", null ],
    [ "ir_remote.c", "ir__remote_8c.html", "ir__remote_8c" ],
    [ "ir_remote.h", "ir__remote_8h.html", "ir__remote_8h" ],
    [ "ir_remote_types.h", "ir__remote__types_8h.html", "ir__remote__types_8h" ],
    [ "irrecord.c", "irrecord_8c.html", "irrecord_8c" ],
    [ "irrecord.h", "irrecord_8h.html", "irrecord_8h" ],
    [ "line_buffer.cpp", "line__buffer_8cpp.html", null ],
    [ "line_buffer.h", "line__buffer_8h.html", [
      [ "LineBuffer", "classLineBuffer.html", "classLineBuffer" ]
    ] ],
    [ "lirc-utils.c", "lirc-utils_8c.html", "lirc-utils_8c" ],
    [ "lirc-utils.h", "lirc-utils_8h.html", "lirc-utils_8h" ],
    [ "lirc_client.c", "lirc__client_8c.html", "lirc__client_8c" ],
    [ "lirc_client.h", "lirc__client_8h.html", "lirc__client_8h" ],
    [ "lirc_config.h", "lirc__config_8h.html", "lirc__config_8h" ],
    [ "lirc_driver.h", "lirc__driver_8h.html", "lirc__driver_8h" ],
    [ "lirc_log.c", "lirc__log_8c.html", "lirc__log_8c" ],
    [ "lirc_log.h", "lirc__log_8h.html", "lirc__log_8h" ],
    [ "lirc_options.c", "lirc__options_8c.html", "lirc__options_8c" ],
    [ "lirc_options.h", "lirc__options_8h.html", "lirc__options_8h" ],
    [ "lirc_private.h", "lirc__private_8h.html", null ],
    [ "paths.h", "paths_8h_source.html", null ],
    [ "receive.c", "receive_8c.html", "receive_8c" ],
    [ "receive.h", "receive_8h.html", "receive_8h" ],
    [ "release.c", "release_8c.html", "release_8c" ],
    [ "release.h", "release_8h.html", "release_8h" ],
    [ "serial.c", "serial_8c.html", "serial_8c" ],
    [ "serial.h", "serial_8h.html", "serial_8h" ],
    [ "transmit.c", "transmit_8c.html", "transmit_8c" ],
    [ "transmit.h", "transmit_8h.html", "transmit_8h" ]
];
